import Foundation
import SQLite

struct DBMetadata {
    
    private static let table = Table("metadata_values")
    
    private static let rowKeyId = Expression<Int?>("key_id")
    
    private static let rowObjectId = Expression<Int?>("object_id")
    
    private static let rowValueType = Expression<Int>("value_type")
    
    private static let rowStringValue = Expression<String?>("string_value")
    
    private static let rowNumericalValue = Expression<Double?>("numerical_value")
    
    private static let rowDateValue = Expression<Double?>("date_value")
    
    private static let rowDataValue = Expression<Data?>("data_value")
    
    static func readAll(in database: Connection) throws -> [Self] {
        try database.prepare(table).map(Self.init)
    }
    
    static func metadata(for workoutId: Int, in database: Connection) throws -> [Self] {
        try database.prepare(table.filter(rowObjectId == workoutId)).map(Self.init)
    }
    
    let keyId: Int?
    
    let objectId: Int?
    
    let valueType: Int
    
    let string: String?
    
    let number: Double?
    
    let date: Double?

    let data: Data?
}

extension DBMetadata {
    
    init(row: Row) {
        self.keyId = row[DBMetadata.rowKeyId]
        self.objectId = row[DBMetadata.rowObjectId]
        self.valueType = row[DBMetadata.rowValueType]
        self.string = row[DBMetadata.rowStringValue]
        self.number = row[DBMetadata.rowNumericalValue]
        self.date = row[DBMetadata.rowDateValue]
        self.data = row[DBMetadata.rowDataValue]
    }
}

