import Foundation
import SQLite

struct DBWorkoutActivity {
    
    private static let table = Table("workout_activities")
    
    private static let rowId = Expression<Int>("ROWID")
    
    private static let rowUUID = Expression<Data>("uuid")
    
    private static let rowOwnerId = Expression<Int>("owner_id")
    
    private static let rowIsPrimaryActivity = Expression<Bool>("is_primary_activity")
    
    private static let rowActivityType = Expression<Int>("activity_type")
    
    private static let rowLocationType = Expression<Int>("location_type")
    
    private static let rowSwimmingLocationType = Expression<Int>("swimming_location_type")
    
    private static let rowLapLength = Expression<Data?>("lap_length")
    
    private static let rowStartDate = Expression<Double>("start_date")
    
    private static let rowEndDate = Expression<Double>("end_date")
    
    private static let rowDuration = Expression<Double>("duration")
    
    private static let rowMetadata = Expression<Data?>("metadata")
    
    static func readAll(in database: Connection) throws -> [Self] {
        try database.prepare(table).map(Self.init)
    }
    
    static func activities(for workoutId: Int, in database: Connection) throws -> [Self] {
        try database.prepare(table.filter(rowOwnerId == workoutId)).map(Self.init)
    }
    
    let id: Int
    
    let uuid: Data
    
    let ownerId: Int
    
    let isPrimaryActivity: Bool
    
    let activityType: Int
    
    let locationType: Int
    
    let swimmingLocationType: Int
    
    let lapLength: Data?
    
    #warning("Fix timezone for dates")
    let startDate: Double
    
    let endDate: Double
    
    let duration: Double
    
    let metadata: Data?
    
    init(row: Row) {
        self.id = row[DBWorkoutActivity.rowId]
        self.uuid = row[DBWorkoutActivity.rowUUID]
        self.ownerId = row[DBWorkoutActivity.rowOwnerId]
        self.isPrimaryActivity = row[DBWorkoutActivity.rowIsPrimaryActivity]
        self.activityType = row[DBWorkoutActivity.rowActivityType]
        self.locationType = row[DBWorkoutActivity.rowLocationType]
        self.swimmingLocationType = row[DBWorkoutActivity.rowSwimmingLocationType]
        self.lapLength = row[DBWorkoutActivity.rowLapLength]
        self.startDate = row[DBWorkoutActivity.rowStartDate]
        self.endDate = row[DBWorkoutActivity.rowEndDate]
        self.duration = row[DBWorkoutActivity.rowDuration]
        self.metadata = row[DBWorkoutActivity.rowMetadata]
    }
}
