import Foundation
import SQLite

struct DBWorkoutEvent {
    
    private static let table = Table("workout_events")
    
    private static let rowOwnerId = Expression<Int>("owner_id")
    
    private static let rowDate = Expression<Double>("date")
    
    private static let rowType = Expression<Int>("type")
    
    private static let rowDuration = Expression<Double>("duration")
    
    private static let rowMetadata = Expression<Data?>("metadata")
    
    private static let rowSessionUUID = Expression<Data?>("session_uuid")
    
    private static let rowError = Expression<Data?>("error")
    
    static func readAll(in database: Connection) throws -> [Self] {
        try database.prepare(table).map(Self.init)
    }
    
    static func events(for workoutId: Int, in database: Connection) throws -> [Self] {
        try database.prepare(table.filter(rowOwnerId == workoutId)).map(Self.init)
    }
    
    let ownerId: Int
    
    let date: Double
    
    let type: Int
    
    let duration: Double
    
    let metadata: Data?
    
    let sessionUUID: Data?
    
    let error: Data?
    
    init(row: Row) {
        self.ownerId = row[DBWorkoutEvent.rowOwnerId]
        self.date = row[DBWorkoutEvent.rowDate]
        self.type = row[DBWorkoutEvent.rowType]
        self.duration = row[DBWorkoutEvent.rowDuration]
        self.metadata = row[DBWorkoutEvent.rowMetadata]
        self.sessionUUID = row[DBWorkoutEvent.rowSessionUUID]
        self.error = row[DBWorkoutEvent.rowError]
    }
}
