import Foundation
import SQLite

final class HealthDatabase: ObservableObject {
    
    let fileUrl: URL
    
    let database: Connection
    
    @Published
    var workouts: [Workout] = []
    
    init(fileUrl: URL) throws {
        self.fileUrl = fileUrl
        self.database = try Connection(fileUrl.path)
        DispatchQueue.global().async {
            self.readAllWorkouts()
        }
    }
    
    func readAllWorkouts() {
        do {
            let dbWorkouts = try DBWorkout.readAll(in: database)
            let metadataKeys = try DBMetadataKey.readAll(in: database)
            let workouts = try dbWorkouts.map { entry in
                let events = try DBWorkoutEvent.events(for: entry.dataId, in: database)
                let activities = try DBWorkoutActivity.activities(for: entry.dataId, in: database)
                let metadata: [String : MetadataValue] = try DBMetadata.metadata(for: entry.dataId, in: database).reduce(into: [:]) { dict, item in
                    let key = metadataKeys[item.keyId!]!
                    dict[key] = MetadataValue(entry: item)
                }
                return Workout(entry: entry, events: events, activities: activities, metadata: metadata)
            }
            
            DispatchQueue.main.async {
                self.workouts = workouts
            }
        } catch {
            print("Failed to read workouts: \(error)")
        }
    }
}
