import Foundation
import HealthKit

struct WorkoutActivity {
    
    let uuid: Data
    
    let isPrimaryActivity: Bool
    
    let activityType: HKWorkoutActivityType
    
    let locationType: HKWorkoutSessionLocationType
    
    let swimmingLocationType: HKWorkoutSwimmingLocationType
    
    let lapLength: Data?
    
    let startDate: Date
    
    let endDate: Date
    
    let duration: TimeInterval
    
    let metadata: Data?
}

extension WorkoutActivity {
    
    init(entry: DBWorkoutActivity) {
        self.uuid = entry.uuid
        self.isPrimaryActivity = entry.isPrimaryActivity
        self.activityType = .init(rawValue: UInt(entry.activityType))!
        self.locationType = .init(rawValue: entry.locationType)!
        self.swimmingLocationType = .init(rawValue: entry.swimmingLocationType)!
        self.lapLength = entry.lapLength
        self.startDate = Date(timeIntervalSinceReferenceDate: entry.startDate)
        self.endDate = Date(timeIntervalSinceReferenceDate: entry.endDate)
        self.duration = entry.duration
        self.metadata = entry.metadata
    }
}

extension WorkoutActivity: Equatable {
    
    static func == (lhs: WorkoutActivity, rhs: WorkoutActivity) -> Bool {
        lhs.uuid == rhs.uuid
    }
}

extension WorkoutActivity: Comparable {
    
    static func < (lhs: WorkoutActivity, rhs: WorkoutActivity) -> Bool {
        lhs.startDate < rhs.startDate
    }
}

extension WorkoutActivity: Hashable {
    
    func hash(into hasher: inout Hasher) {
        hasher.combine(uuid)
    }
}
