import Foundation
import HealthKit

struct WorkoutEvent {
    
    let date: Date
    
    let type: HKWorkoutEventType
    
    let duration: TimeInterval
    
    let metadata: Data?
    
    let sessionUUID: Data?
    
    let error: Data?
    
}

extension WorkoutEvent {
    
    init(entry: DBWorkoutEvent) {
        self.date = Date(timeIntervalSinceReferenceDate: entry.date)
        self.type = .init(rawValue: entry.type)!
        self.duration = entry.duration
        self.metadata = entry.metadata
        self.sessionUUID = entry.sessionUUID
        self.error = entry.error
    }
}

extension WorkoutEvent: Equatable {
    
    static func == (lhs: WorkoutEvent, rhs: WorkoutEvent) -> Bool {
        lhs.date == rhs.date
    }
}

extension WorkoutEvent: Comparable {
    
    static func < (lhs: WorkoutEvent, rhs: WorkoutEvent) -> Bool {
        lhs.date < rhs.date
    }
}

extension WorkoutEvent: Hashable {
    
    func hash(into hasher: inout Hasher) {
        hasher.combine(date)
    }
}
