import SwiftUI
import Collections

struct WorkoutDetailView: View {
    
    @EnvironmentObject
    var database: HealthDatabase
    
    let workout: Workout
    
    var body: some View {
        List {
            Section("Info") {
                DetailRow("ID", value: workout.id)
                DetailRow("Total Distance", kilometer: workout.totalDistance)
                DetailRow("Goal Type", value: workout.goalType)
                DetailRow("Goal", value: workout.goal)
                DetailRow("Condenser Version", value: workout.condenserVersion)
                DetailRow("Condenser Date", date: workout.condenserDate)
            }
            if !workout.events.isEmpty {
                Section("Events") {
                    ForEach(workout.events, id: \.date) { event in
                        NavigationLink(value: event) {
                            DetailRow(event.type.description, date: event.date)
                        }
                    }
                }
            }
            if !workout.activities.isEmpty {
                Section("Activities") {
                    ForEach(workout.activities, id: \.startDate) { activity in
                        NavigationLink(value: activity) {
                            DetailRow(activity.activityType.description,
                                      date: activity.startDate)
                        }
                        
                    }
                }
            }
            if !workout.metadata.isEmpty {
                ForEach(workout.metadata.elements, id:\.key) { (key, value) in
                    DetailRow(key, value: value)
                }
            }
        }
        .navigationTitle(workout.typeString)
        .navigationDestination(for: WorkoutActivity.self) { activity in
            ActivityDetailView(activity: activity)
        }
        .navigationDestination(for: WorkoutEvent.self) { event in
            EventDetailView(event: event)
        }
    }
}

#Preview {
    NavigationStack {
        WorkoutDetailView(workout: .init(
            id: 123,
            totalDistance: 234.5,
            goalType: 3,
            goal: 345.6,
            condenserVersion: 1,
            condenserDate: .now,
            events: [
                .init(
                    date: .now,
                    type: .pause,
                    duration: 12.3,
                    metadata: .init(repeating: 42, count: 2),
                    sessionUUID: .init(repeating: 42, count: 3),
                    error: nil)
            ],
            activities: [
                .init(
                    uuid: .init(repeating: 42, count: 3),
                    isPrimaryActivity: true,
                    activityType: .running,
                    locationType: .outdoor,
                    swimmingLocationType: .unknown,
                    lapLength: .init(repeating: 42, count: 3),
                    startDate: .now.addingTimeInterval(-100),
                    endDate: .now,
                    duration: 100.0,
                    metadata: .init(repeating: 42, count: 3))
            ]))
    }
}

extension String: Identifiable {
    
    public var id: Self { self }
}
